@@ -75,6 +75,8 @@ sidra_download = function(sidra_code = NULL,year,geo_level = 'municipality',
       tibble::as_tibble() %>%
       janitor::clean_names()
 
+    if (nrow(dat) == 0) {stop("Error in Download.")}
+
     base::message(base::cat('Download Succesfully Completed!'))
 
     return(dat)
@@ -819,3 +821,20 @@ datasets_link = function(){
   return(link)
 
 }
+
+datasets_seeg = function(){
+
+  ## Add file type at the end in order to set the Curl Process
+
+  link = tibble::tribble(~survey,~dataset,~id_code,~link,
+
+                         'SEEG','seeg_farming',100,'http://seeg.eco.br/download',
+                         'SEEG','seeg_industry',101,'http://seeg.eco.br/download',
+                         'SEEG','seeg_energy',102,'http://seeg.eco.br/download',
+                         'SEEG','seeg_land',103,'http://seeg.eco.br/download',
+                         'SEEG','seeg_residuals',104,'http://seeg.eco.br/download',
+
+
+  )
+  return(link)
+}
